@@ -21,6 +21,8 @@ from cubicweb import typed_eid
 from cubicweb.server import hook
 from cubicweb.selectors import is_instance
 
+from cubes.tracker import hooks as tracker
+
 TICKET_EID_RGX = re.compile('#(\d+)')
 
 class SearchRevisionTicketOp(hook.DataOperationMixIn,
@@ -36,7 +38,7 @@ class SearchRevisionTicketOp(hook.DataOperationMixIn,
         for rev in self.get_data():
             # search for instruction
             for line in rev.description.splitlines():
-                words = [w.lower() for w in line.strip().split()]
+                words = [w.lower() for w in re.findall('#?\w+', line.strip())]
                 try:
                     idx = words.index('closes')
                 except ValueError:
@@ -66,6 +68,12 @@ class RevisionAdded(hook.Hook):
             SearchRevisionTicketOp.get_instance(self._cw).add_data(self.entity)
 
 
+tracker.S_RELS |= set(('source_repository', 'has_patch_repository',
+                       'patch_revision',
+                       'has_activity', ))
+tracker.O_RELS |= set(('patch_repository', 'point_of',))
+
+
 def registration_callback(vreg):
     if vreg.config['trusted-vcs-repositories']:
         vreg.register(RevisionAdded)
